<?php
/* -----------------------------------------------------------------------------
  Plugin     : GMaps
  Author     : Grum
    email    : grum@piwigo.org
    website  : http://photos.grum.fr

    << May the Little SpaceFrog be with you ! >>
  ------------------------------------------------------------------------------
  See main.inc.php for release information


  --------------------------------------------------------------------------- */

  if(!defined('PHPWG_ROOT_PATH')) die('Hacking attempt!');

  include_once(PHPWG_PLUGINS_PATH.'GrumPluginClasses/classes/GPCRequestBuilder.class.inc.php');

load_language('plugin.lang', GMAPS_PATH);

class RBCallBackGMaps extends GPCSearchCallback {

  /**
   * the getImageId returns the name of the image id attribute
   * return String
   */
  static public function getImageId()
  {
    return("pgc.imageId");
  }

  /**
   * the getSelect function must return an attribute list separated with a comma
   *
   * "att1, att2, att3, att4"
   */
  static public function getSelect($param="")
  {
    return("pgc.latitude, pgc.longitude");
  }

  /**
   * the getFrom function must return a tables list separated with a comma
   *
   * "table1, (table2 left join table3 on table2.key = table3.key), table4"
   */
  static public function getFrom($param="")
  {
    global $prefixeTable;

    return($prefixeTable."gmaps_cache pgc");
  }

  /**
   * the getWhere function must return a ready to use where clause
   *
   * "(att1 = value0 OR att2 = value1) AND att4 LIKE value2 "
   */
  static public function getWhere($param="")
  {
    global $user;

    $returned='';

    if($param['bounds']['east']<$param['bounds']['west'])
    {
      $returned=" (pgc.longitude <= ".$param['bounds']['east']." OR pgc.longitude >= ".$param['bounds']['west'].") ";
    }
    else
    {
      $returned=" (pgc.longitude >= ".$param['bounds']['west']." AND pgc.longitude <= ".$param['bounds']['east'].") ";
    }

    $returned.=" AND pgc.latitude >= ".$param['bounds']['south']."
                 AND pgc.latitude <= ".$param['bounds']['north']."
                 AND pgc.userId='".$user['id']."'
                 AND pgc.requestId='".$param['requestId']."' ";

    return($returned);
  }

  /**
   * the getJoin function must return a ready to use where allowing to join the
   * IMAGES table (key : id) with given conditions
   *
   * "att3 = pit.id "
   */
  static public function getJoin($param="")
  {
    return("pgc.imageId = pit.id");
  }


  /**
   * the getFilter function must return a ready to use where clause
   * this where clause is used to filter the cache when the used tables can
   * return more than one result
   *
   * the filter can be empty, can be equal to the where clause, or can be equal
   * to a sub part of the where clause
   *
   */
  static public function getFilter($param="")
  {
    return(self::getWhere($param));
  }

  /**
   * this function is called by the request builder, allowing to display plugin
   * data with a specific format
   *
   * @param Array $attributes : array of ('attribute_name' => 'attribute_value')
   * @return String : HTML formatted value
   */
  static public function formatData($attributes)
  {
    /* attributes is an array :
     *    Array(
     *      'csColors' => 'color1,color2,color3,...,colorN',
     *      'csColorsPct' => 'pct1,pct2,pct3,...,pctN'
     *    );
     */
    $returned=l10n('gmaps_geolocation')."&nbsp;:&nbsp;";

    if($attributes['latitude']<0)
    {
      $returned.=GMaps_functions::DDtoDMS(abs($attributes['latitude'])).'&nbsp;'.l10n('gmaps_south');
    }
    else
    {
      $returned.=GMaps_functions::DDtoDMS($attributes['latitude']).'&nbsp;'.l10n('gmaps_north');
    }

    $returned.=', ';

    if($attributes['longitude']<0)
    {
      $returned.=GMaps_functions::DDtoDMS(abs($attributes['longitude'])).'&nbsp;'.l10n('gmaps_west');
    }
    else
    {
      $returned.=GMaps_functions::DDtoDMS($attributes['longitude']).'&nbsp;'.l10n('gmaps_east');
    }

    return($returned);
  }



  /**
   * this function is called by the request builder to make the search page, and
   * must return the HTML & JS code of the dialogbox used to select criterion
   *
   * Notes :
   *  - the dialogbox is a JS object with a public method 'show'
   *  - when the method show is called, one parameter is given by the request
   *    builder ; the parameter is an object defined as this :
   *      {
   *        cBuilder: an instance of the criteriaBuilder object used in the page,
   *        eventOK : a callback function, called when the OK button is pushed
   *        id:
   *      }
   *
   *
   *
   *
   * @param String $mode : can take 'admin' or 'public' values, allowing to
   *                       return different interface if needed
   * @return String : HTML formatted value
   */
  static public function getInterfaceContent($mode='admin')
  {
    return(GMaps_functions::dialogBoxGMaps());
  }

  /**
   * this function returns the label displayed in the criterion menu
   *
   * @return String : label displayed in the criterions menu
   */
  static public function getInterfaceLabel()
  {
    return(l10n('gmaps_add_geographic_area'));
  }

  /**
   * this function returns the name of the dialog box class
   *
   * @return String : name of the dialogbox class
   */
  static public function getInterfaceDBClass()
  {
    return('dialogChooseGMapsBox');
  }

}

?>
